==> devspaces-dashboard-rhel8-container-3.9-30.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/.deps/EXCLUDED/dev.md <==
This file contains a manual contribution to .deps/dev.md and it's needed because eclipse/dash-licenses does not deal with work-with CQs (more see https://github.com/eclipse/dash-licenses/issues/13)

| Packages | Resolved CQs |
| --- | --- |
| `@babel/runtime-corejs3@7.22.10` | transitive dependency |
| `@csstools/media-query-list-parser@2.1.4` | transitive dependency |
| `@csstools/selector-specificity@3.0.0` | transitive dependency |
| `@nrwl/nx-darwin-arm64@15.9.4` | transitive dependency |
| `@nrwl/nx-darwin-x64@15.9.4` | transitive dependency |
| `@nrwl/nx-linux-arm-gnueabihf@15.9.4` | transitive dependency |
| `@nrwl/nx-linux-arm64-gnu@15.9.4` | transitive dependency |
| `@nrwl/nx-linux-arm64-musl@15.9.4` | transitive dependency |
| `@nrwl/nx-win32-arm64-msvc@15.9.4` | transitive dependency |
| `@nrwl/nx-win32-x64-msvc@15.9.4` | transitive dependency |
| `@sigstore/bundle@1.1.0` | transitive dependency |
| `@sigstore/sign@1.0.0` | transitive dependency |
| `@sigstore/sign@1.0.0` | transitive dependency |
| `@testing-library/dom@7.31.2` | (clearlydefined)[https://clearlydefined.io/definitions/npm/npmjs/@testing-library/dom/7.31.2] |
| `@typescript-eslint/eslint-plugin@6.4.0` | transitive dependency |
| `@typescript-eslint/parser@6.4.0` | transitive dependency |
| `@typescript-eslint/scope-manager@6.4.0` | transitive dependency |
| `@typescript-eslint/type-utils@6.4.0` | transitive dependency |
| `@typescript-eslint/types@6.4.0` | transitive dependency |
| `@typescript-eslint/typescript-estree@6.4.0` | transitive dependency |
| `@typescript-eslint/utils@6.4.0` | transitive dependency |
| `@typescript-eslint/visitor-keys@6.4.0` | transitive dependency |
| `agentkeepalive@4.5.0` | transitive dependency |
| `asynciterator.prototype@1.0.0` | transitive dependency |
| `es-iterator-helpers@1.0.12` | transitive dependency |
| `es-iterator-helpers@1.0.12` | transitive dependency |
| `eslint-config-prettier@9.0.0` | (clearlydefined)[https://clearlydefined.io/definitions/npm/npmjs/-/eslint-config-prettier/9.0.0] |
| `eslint@8.47.0` | (clearlydefined)[https://clearlydefined.io/definitions/npm/npmjs/-/eslint/8.47.0] |
| `fsevents@2.3.2` | transitive dependency |
| `inquirer@8.2.6` | transitive dependency |
| `jackspeak@2.3.0` | transitive dependency |
| `npm-install-checks@6.2.0` | transitive dependency |
| `postcss-reduce-initial@6.0.0` | transitive dependency |
| `prettier@3.0.2` | (clearlydefined)[https://clearlydefined.io/definitions/npm/npmjs/-/prettier/3.0.2] |
| `sigstore@1.9.0` | transitive dependency |
| `string-width-cjs@4.2.3` | transitive dependency |
| `strip-ansi-cjs@6.0.1` | transitive dependency |
| `wrap-ansi-cjs@7.0.0` | transitive dependency |

==> devspaces-dashboard-rhel8-container-3.10-56.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/.deps/EXCLUDED/dev.md <==
This file contains a manual contribution to .deps/dev.md and it's needed because eclipse/dash-licenses does not deal with work-with CQs (more see https://github.com/eclipse/dash-licenses/issues/13)

| Packages | Resolved CQs |
| --- | --- |
| `@babel/runtime-corejs3@7.22.10` | transitive dependency |
| `@csstools/media-query-list-parser@2.1.4` | transitive dependency |
| `@csstools/selector-specificity@3.0.0` | transitive dependency |
| `@nrwl/nx-darwin-arm64@15.9.4` | transitive dependency |
| `@nrwl/nx-darwin-x64@15.9.4` | transitive dependency |
| `@nrwl/nx-linux-arm-gnueabihf@15.9.4` | transitive dependency |
| `@nrwl/nx-linux-arm64-gnu@15.9.4` | transitive dependency |
| `@nrwl/nx-linux-arm64-musl@15.9.4` | transitive dependency |
| `@nrwl/nx-win32-arm64-msvc@15.9.4` | transitive dependency |
| `@nrwl/nx-win32-x64-msvc@15.9.4` | transitive dependency |
| `@sigstore/bundle@1.1.0` | transitive dependency |
| `@sigstore/sign@1.0.0` | transitive dependency |
| `@sigstore/sign@1.0.0` | transitive dependency |
| `@testing-library/dom@7.31.2` | [clearlydefined](https://clearlydefined.io/definitions/npm/npmjs/@testing-library/dom/7.31.2) |
| `@typescript-eslint/eslint-plugin@6.4.0` | transitive dependency |
| `@typescript-eslint/parser@6.4.0` | transitive dependency |
| `@typescript-eslint/scope-manager@6.4.0` | transitive dependency |
| `@typescript-eslint/type-utils@6.4.0` | transitive dependency |
| `@typescript-eslint/types@6.4.0` | transitive dependency |
| `@typescript-eslint/typescript-estree@6.4.0` | transitive dependency |
| `@typescript-eslint/utils@6.4.0` | transitive dependency |
| `@typescript-eslint/visitor-keys@6.4.0` | transitive dependency |
| `agentkeepalive@4.5.0` | transitive dependency |
| `asynciterator.prototype@1.0.0` | transitive dependency |
| `es-iterator-helpers@1.0.12` | transitive dependency |
| `es-iterator-helpers@1.0.12` | transitive dependency |
| `eslint-config-prettier@9.0.0` | [clearlydefined](https://clearlydefined.io/definitions/npm/npmjs/-/eslint-config-prettier/9.0.0) |
| `eslint@8.47.0` | [clearlydefined](https://clearlydefined.io/definitions/npm/npmjs/-/eslint/8.47.0) |
| `fsevents@2.3.2` | transitive dependency |
| `inquirer@8.2.6` | transitive dependency |
| `jackspeak@2.3.0` | transitive dependency |
| `npm-install-checks@6.2.0` | transitive dependency |
| `postcss-reduce-initial@6.0.0` | transitive dependency |
| `prettier@3.0.2` | [clearlydefined](https://clearlydefined.io/definitions/npm/npmjs/-/prettier/3.0.2) |
| `sigstore@1.9.0` | transitive dependency |
| `string-width-cjs@4.2.3` | transitive dependency |
| `strip-ansi-cjs@6.0.1` | transitive dependency |
| `wrap-ansi-cjs@7.0.0` | transitive dependency |
